Method: Progressor::LimitedSequence#elapsed_time

Defined in:
lib/progressor/limited_sequence.rb

#elapsed_timeObject

Returns the time since the object was instantiated, formatted like all the other durations. Useful for a final message to compare initial estimation to actual elapsed time.



124
125
126
# File 'lib/progressor/limited_sequence.rb', line 124

def elapsed_time
  format_time(Time.now - @start_time)
end